@@ -7,8 +7,8 @@ use Carp;
 
 use MooX 'late';
 
-use XML::GrammarBase::Role::RelaxNG;
-use XML::GrammarBase::Role::XSLT;
+use XML::GrammarBase::Role::RelaxNG v0.2.2;
+use XML::GrammarBase::Role::XSLT v0.2.2;
 
 with ('XML::GrammarBase::Role::RelaxNG');
 with XSLT(output_format => 'docbook');
@@ -22,7 +22,7 @@ has '+to_docbook_xslt_transform_basename' =>
 );
 
 
-our $VERSION = '0.14.4';
+our $VERSION = '0.14.5';
 
 
 
@@ -48,11 +48,11 @@ DocBook 5.
 
 =head1 VERSION
 
-version 0.14.4
+version 0.14.5
 
 =head1 VERSION
 
-Version 0.14.4
+Version 0.14.5
 
 =head1 METHODS
 
